%global udevrules_prefix 60-

Summary:       TPM2.0 Software Stack
Name:          tpm2-tss
Version:       4.0.1
Release:       6%{?dist}
License:       BSD and TCGL
URL:           https://github.com/tpm2-software/tpm2-tss
Source0:       https://github.com/tpm2-software/tpm2-tss/releases/download/%{version}/%{name}-%{version}.tar.gz

Patch0001:     0001-FAPI-Fix-check-of-magic-number-in-verify-quote.patch
Patch5001:     5001-esys-add-SM4-algorithm-support.patch
Patch5002:     5002-add-bootstrap-file.patch

BuildRequires: gcc gcc-c++ make pkgconfig systemd doxygen
BuildRequires: json-c-devel libcurl-devel libgcrypt-devel openssl-devel libuuid-devel
BuildRequires: autoconf libtool automake
Requires(pre): shadow-utils

%description
tpm2-tss is a software stack supporting Trusted Platform Module(TPM) 2.0 system
APIs. It sits between TPM driver and applications, providing TPM2.0 specified
APIs for applications to access TPM module through kernel TPM drivers.

%package        devel
Summary:        Headers and libraries for building apps that use tpm2-tss
Requires:       %{name} = %{version}-%{release}

%description    devel
This package contains headers and libraries required to build applications that
use tpm2-tss.

%prep
%autosetup -n %{name}-%{version} -p1

%build
./bootstrap
%configure --disable-static \
    --disable-silent-rules \
    --with-udevrulesdir=%{_udevrulesdir} \
    --with-udevrulesprefix=%{udevrules_prefix} \
    --with-runstatedir=%{_rundir} \
    --with-tmpfilesdir=%{_tmpfilesdir} \
    --with-sysusersdir=%{_sysusersdir}

%make_build

%install
%make_install
find %{buildroot}%{_libdir} -type f -name \*.la -delete

%check
make check

%pre
getent group tss >/dev/null || groupadd -f -g 59 -r tss
if ! getent passwd tss >/dev/null ; then
    if ! getent passwd 59 >/dev/null ; then
      useradd -r -u 59 -g tss -d /dev/null -s /sbin/nologin -c "Account used for TPM access" tss
    else
      useradd -r -g tss -d /dev/null -s /sbin/nologin -c "Account used for TPM access" tss
    fi
fi
exit 0

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%license LICENSE
%doc README.md CHANGELOG.md
%{_sysconfdir}/tpm2-tss/
%{_libdir}/libtss2-mu.so.0*
%{_libdir}/libtss2-sys.so.1*
%{_libdir}/libtss2-esys.so.0*
%{_libdir}/libtss2-fapi.so.1*
%{_libdir}/libtss2-rc.so.0*
%{_libdir}/libtss2-policy.so.0*
%{_libdir}/libtss2-tctildr.so.0*
%{_libdir}/libtss2-tcti-cmd.so.0*
%{_libdir}/libtss2-tcti-device.so.0*
%{_libdir}/libtss2-tcti-mssim.so.0*
%{_libdir}/libtss2-tcti-pcap.so.0*
%{_libdir}/libtss2-tcti-swtpm.so.0*
%{_libdir}/libtss2-tcti-spi-helper.so.0*
%{_sysusersdir}/tpm2-tss.conf
%{_tmpfilesdir}/tpm2-tss-fapi.conf
%{_udevrulesdir}/%{udevrules_prefix}tpm-udev.rules

%files devel
%{_includedir}/tss2/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*.3.gz
%{_mandir}/man5/*.5.gz
%{_mandir}/man7/tss2*.7.gz

%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.0.1-6
- Rebuilt for loongarch release

* Mon Jul 15 2024 Sinong Chen <costinchen@tencent.com> - 4.0.1-5
- Fix CVE-2024-29040

* Tue May 21 2024 chench <chench@hygon.cn> - 4.0.1-4
- add SM4 algorithm support from upstream

* Thu Oct 12 2023 Miaojun Dong <zoedong@tencent.com> - 4.0.1-3
- Rebuild for curl-8.4.0

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.0.1-2
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Aug 17 2023 cunshunxia <cunshunxia@tencent.com> - 4.0.1-1
- upgrade to 4.0.1

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.2.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.2.0-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Jun 28 2022 Anakin Zhang <anakinzhang@tencent.com> - 3.2.0-1
- Initial build
